import React, { Component } from "react";
import { injectIntl } from "react-intl";
import { withTheme, withStyles } from "@material-ui/core/styles";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import { Button, Grid } from "@material-ui/core";
import { TextInput, journalize, PublishedComponent } from "@openimis/fe-core";
import { saveEntity } from "../actions";

const styles = theme => ({
    page: theme.page,
});

class MyEntityPage extends Component {


    state = {
        edited: {}
    }


    componentDidUpdate(prevProps, prevState, snapshot) {
        if (prevProps.submittingMutation && !this.props.submittingMutation) {
            this.props.journalize(this.props.mutation);
        }
    }


    save = e => {
        this.props.saveEntity(this.state.edited, `Creating ${this.state.edited.code}`)
    }

    updateAttribute = (k, v) => {
        this.setState((state) => ({
            edited: { ...state.edited, [k]: v }
        }))
    }


    render() {
        const { classes } = this.props;
        const { edited } = this.state;

        return (
            <div className={classes.page}>
                <Grid container>
                    <Grid item>
                        <TextInput
                            module="my_module" label="MyEntityForm.code"
                            value={edited.code}
                            required={true}
                            inputProps={{
                                "maxLength": this.codeMaxLength,
                            }}
                            onChange={v => this.updateAttribute("code", v)}
                        />
                    </Grid>
                    <Grid item>
                        <TextInput
                            module="my_module" label="MyEntityForm.name"
                            value={edited.name}
                            required={true}
                            onChange={v => this.updateAttribute("name", v)}
                        />
                    </Grid>                 
                    <Grid item>
                        <PublishedComponent
                            pubRef="location.LocationTypePicker"
                            value={edited.type}
                            required={true}
                            onChange={v => this.updateAttribute("type", v)}
                        />
                    </Grid>   
                </Grid>
                <br />
                <Button onClick={this.save} >SAVE</Button>
            </div>
        )
    }
}


const mapStateToProps = (state, props) => ({
    submittingMutation: state.my_module.submittingMutation,
    mutation: state.my_module.mutation,
});

const mapDispatchToProps = dispatch => {
    return bindActionCreators({ saveEntity, journalize }, dispatch);
};

export default injectIntl(withTheme(withStyles(styles)(connect(mapStateToProps, mapDispatchToProps)(MyEntityPage))));